#
# spec file for package certbot
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           certbot
Version:        0.15.0
Release:        1.2
Summary:        Let's Encrypt
License:        Apache-2.0
Group:          Productivity/Security
Url:            https://certbot.eff.org/
Source0:        https://github.com/certbot/certbot/archive/v%{version}.tar.gz
Source1:        %{name}.cron
Source90:       README.SUSE
Source99:       %{name}.rpmlintrc
Patch0:         %{name}-cli.ini.patch
Patch1:         %{name}-fix_constants.patch
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cron
BuildRequires:  dialog
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  python-setuptools >= 1.0
BuildRequires:  swig
BuildRequires:  unzip
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python) >= 2.6.6
# install_requires
#BuildRequires:  acme
BuildRequires:  python-acme = %{version}
BuildRequires:  python-argparse
BuildRequires:  python-configargparse
BuildRequires:  python-configobj
BuildRequires:  python-cryptography >= 0.8
BuildRequires:  python-dialog >= 3.2.2rc1
BuildRequires:  python-future
BuildRequires:  python-jsonschema
BuildRequires:  python-mock
BuildRequires:  python-parsedatetime
BuildRequires:  python-psutil >= 2.2.1
BuildRequires:  python-pyOpenSSL >= 0.15
BuildRequires:  python-pyRFC3339
BuildRequires:  python-pytz
%if 0%{?suse_version} >= 1330
BuildRequires:  python2-requests >= 2.10
%else
BuildRequires:  python-requests >= 2.10
%endif
BuildRequires:  python-six
BuildRequires:  python-zope.component
BuildRequires:  python-zope.interface
# dev_extras
BuildRequires:  python-astroid >= 1.3.5
BuildRequires:  python-pylint >= 1.4.2
BuildRequires:  python-twine
BuildRequires:  python-wheel
# docs_extras
BuildRequires:  python-Sphinx >= 1.0
BuildRequires:  python-autodoc
BuildRequires:  python-repoze.sphinx.autointerface
BuildRequires:  python-sphinx_rtd_theme
BuildRequires:  python-sphinxcontrib-programoutput
# testing_extras
BuildRequires:  python-coverage
BuildRequires:  python-nose
BuildRequires:  python-nosexcover
BuildRequires:  python-pep8
BuildRequires:  python-tox
# install_requires acme
BuildRequires:  python-ndg-httpsclient
BuildRequires:  python-pyasn1 >= 0.1.7
BuildRequires:  python-pyasn1-modules
BuildRequires:  python-werkzeug
# install_requires apache
BuildRequires:  augeas-lenses
BuildRequires:  python-augeas
# install_requires nginx
BuildRequires:  python-pyparsing >= 1.5.5
# install_requires openSUSE build
BuildRequires:  python-packaging

# requires
Requires:       ca-certificates
Requires:       cron
Requires:       python-acme = %{version}
Requires:       python-argparse
Requires:       python-certbot = %{version}
Requires:       python-configargparse
Requires:       python-configobj
Requires:       python-cryptography >= 0.8
Requires:       python-dialog >= 3.2.2rc1
Requires:       python-mock
Requires:       python-parsedatetime
Requires:       python-psutil >= 2.2.1
Requires:       python-pyOpenSSL >= 0.15
Requires:       python-pyRFC3339
Requires:       python-pytz
%if 0%{?suse_version} >= 1330
Requires:       python2-requests >= 2.10
%else
Requires:       python-requests >= 2.10
%endif
Requires:       python-setuptools >= 1.0
Requires:       python-six
Requires:       python-zope.component
Requires:       python-zope.interface

Obsoletes:      letsencrypt < %{version}
Provides:       letsencrypt = %{version}

%description
Certbot (previously, the Let's Encrypt client) is an easy-to-use automatic client that fetches and deploys 
SSL/TLS certificates for your webserver. 
Certbot was developed by EFF and others as a client for Let’s Encrypt and was previously known as 
“the official Let’s Encrypt client” or “the Let’s Encrypt Python client.” 
Certbot will also work with any other CAs that support the ACME protocol.

While there are many other clients that implement the ACME protocol to fetch certificates, Certbot is the
most extensive client and can automatically configure your webserver to start serving over HTTPS immediately. 
For Apache, it can also optionally automate security tasks such as tuning ciphersuites and enabling important 
security features such as HTTP → HTTPS redirects, OCSP stapling, HSTS, and upgrade-insecure-requests.

Certbot is part of EFF’s larger effort to encrypt the entire Internet. Websites need to use HTTPS to secure 
the web. Along with HTTPS Everywhere, Certbot aims to build a network that is more structurally private,
safe, and protected against censorship.

%package doc
Summary:        Documentation for Certbot
Group:          Documentation/Other

%description doc
epub and html documentation for Certbot

%package -n letshelp-certbot
Summary:        Simple help script for Let’s Encrypt Project
Group:          Development/Libraries/Python
Requires:       apache2
Requires:       python-mock
Obsoletes:      letshelp-letsencrypt < %{version}
Provides:       letshelp-letsencrypt = %{version}

%description -n letshelp-certbot
Let's Help is a simple script you can run to help out the Let's Encrypt
project. Since Let's Encrypt will support automatically configuring HTTPS on
many servers, we want to test this functionality on as many configurations as
possible. This script will create a sanitized copy of your Apache
configuration, notifying you of the files that have been selected. If (and only
if) you approve this selection, these files will be sent to the Let's Encrypt
developers.

%package -n python-certbot
Summary:        Python module for Certbot 
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python-future
Obsoletes:      python-letsencrypt < %{version}
Provides:       python-letsencrypt = %{version}

%description -n python-certbot
The Python module for Certbot.

%package -n python-certbot-apache
Summary:        Apache plugin for Certbot 
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       apache2
Requires:       augeas-lenses
Requires:       python-augeas
Obsoletes:      python-letsencrypt-apache < %{version}
Provides:       python-letsencrypt-apache = %{version}

%description -n python-certbot-apache
The Apache plugin for Certbot.

%package -n python-certbot-nginx
Summary:        Nginx plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       nginx
Requires:       python-pyparsing >= 1.5.5
Obsoletes:      python-letsencrypt-nginx < %{version}
Provides:       python-letsencrypt-nginx = %{version}

%description -n python-certbot-nginx
The Nginx plugin for Certbot.

%package -n python-certbot-dns-cloudflare
Summary:        Cloudflare Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-cloudflare
Cloudflare DNS Authenticator plugin for Certbot.

%package -n python-certbot-dns-cloudxns
Summary:        Cloudxns Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-cloudxns
Cloudxns DNS Authenticator plugin for Certbot.

%package -n python-certbot-dns-digitalocean
Summary:        Digitalocean Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-digitalocean
Digitalocean DNS Authenticator plugin for Certbot.

%package -n python-certbot-dns-dnsimple
Summary:        Dnsimple Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-dnsimple
Dnsimple DNS Authenticator plugin for Certbot.

%package -n python-certbot-dns-google
Summary:        Google Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-google
Google DNS Authenticator plugin for Certbot.

%package -n python-certbot-dns-nsone
Summary:        Nsone Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-nsone
Nsone DNS Authenticator plugin for Certbot.

%package -n python-certbot-dns-route53
Summary:        Route53 Authenticator plugin for Certbot
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python-certbot-dns-route53
Route53 DNS Authenticator plugin for Certbot.


%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1
install -m644 %{S:90} .
%{__sed} -i 's|PyOpenSSL>=0.15|pyOpenSSL>=0.15|g' setup.py

#Is this still needed?
# certbot-auto not for packages
#sed -i 's/letsencrypt-auto/letsencrypt/g' letsencrypt/cli.py

# rpmlint
find -type f -name ".gitignore" -exec rm {} \;

%build
# build packages certbot, certbot-apache, certbot-nginx, letshelp-certbot 
for PACKAGE in . certbot-apache certbot-nginx letshelp-certbot certbot-dns-cloudflare certbot-dns-cloudxns certbot-dns-digitalocean certbot-dns-dnsimple certbot-dns-google certbot-dns-nsone certbot-dns-route53 ; do
pushd $PACKAGE > /dev/null
python setup.py build
popd > /dev/null
done

# docs certbot
python setup.py install --user
make %{?_smp_mflags} -C docs html PATH=${HOME}/.local/bin:$PATH || true
make %{?_smp_mflags} -C docs epub PATH=${HOME}/.local/bin:$PATH || true
make %{?_smp_mflags} -C docs text PATH=${HOME}/.local/bin:$PATH || true
make %{?_smp_mflags} -C docs man PATH=${HOME}/.local/bin:$PATH || true
rm -rf docs/_build/html/{.buildinfo,_sources}

# docs letshelp-certbot
pushd letshelp-certbot > /dev/null
make %{?_smp_mflags} -C docs html PATH=${HOME}/.local/bin:$PATH || true
make %{?_smp_mflags} -C docs epub PATH=${HOME}/.local/bin:$PATH || true
make %{?_smp_mflags} -C docs text PATH=${HOME}/.local/bin:$PATH || true
make %{?_smp_mflags} -C docs man PATH=${HOME}/.local/bin:$PATH || true
popd > /dev/null

# move docs so i can use one doc-package
mkdir docs/html
mkdir docs/text
mv docs/_build/html docs/html/certbot
mv docs/_build/text docs/text/certbot
mv letshelp-certbot/docs/_build/html docs/html/letshelp-certbot
mv letshelp-certbot/docs/_build/text docs/text/letshelp-certbot

# rpmlint
find -type f -name ".buildinfo" -exec rm {} \;
find -type f -name "jquery.js" -exec dos2unix {} \;

%install
# install packages certbot, certbot-apache, certbot-nginx, letshelp-certbot
for PACKAGE in . certbot-apache certbot-nginx letshelp-certbot certbot-dns-cloudflare certbot-dns-cloudxns certbot-dns-digitalocean certbot-dns-dnsimple certbot-dns-google certbot-dns-nsone certbot-dns-route53 ; do
pushd $PACKAGE > /dev/null
python setup.py install -O1 --skip-build --prefix=%{_prefix} --root=%{buildroot}
popd > /dev/null
done
%fdupes %{buildroot}
# config
install -d -m 0755 %{buildroot}%{_sysconfdir}
install -d -m 0755 %{buildroot}%{_sysconfdir}/certbot
install -d -m 0755 %{buildroot}%{_sysconfdir}/certbot/archive
install -d -m 0755 %{buildroot}%{_sysconfdir}/certbot/keys
install -d -m 0755 %{buildroot}%{_sysconfdir}/certbot/live
# man
install -d -m 0775 %{buildroot}%{_mandir}
install -d -m 0775 %{buildroot}%{_mandir}/man1
install -d -m 0775 %{buildroot}%{_mandir}/man7
cp -a docs/_build/man/*.1 %{buildroot}%{_mandir}/man1/
cp -a docs/_build/man/*.7 %{buildroot}%{_mandir}/man7/
cp -a letshelp-certbot/docs/_build/man/*.1 %{buildroot}%{_mandir}/man1/
# log
install -d -m 0775 %{buildroot}/var/log/%{name}
# cli.ini
install -m 0644 examples/cli.ini %{buildroot}%{_sysconfdir}/%{name}/cli.ini
install -m 0644 examples/dev-cli.ini %{buildroot}%{_sysconfdir}/%{name}/dev-cli.ini
# cron
install -d -m 0755 %{buildroot}%{_sysconfdir}/cron.d
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/cron.d/%{name}

%check
# nginx produce error
#for PACKAGE in . certbot-apache certbot-nginx letshelp-certbot ; do
#pushd $PACKAGE > /dev/null
#python setup.py test
#popd > /dev/null
#done

%files
%defattr(-,root,root)
%doc CHANGES.rst LICENSE.txt README.rst README.SUSE
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/archive
%dir %attr(0700,root,root) %{_sysconfdir}/%{name}/keys
%dir %{_sysconfdir}/%{name}/live
%config(noreplace) %{_sysconfdir}/%{name}/*cli.ini
%config(noreplace) %{_sysconfdir}/cron.d/%{name}
%{_mandir}/*/certbot*
%{_bindir}/%{name}
%dir /var/log/%{name}

%files doc
%defattr(-,root,root)
%doc docs/_build/epub/Certbot.epub
%doc letshelp-certbot/docs/_build/epub/letshelp-certbot.epub
%doc docs/html
%doc docs/text 

%files -n letshelp-certbot
%defattr(-,root,root)
%{_mandir}/*/letshelp*
%{_bindir}/letshelp-certbot-apache
%{python_sitelib}/letshelp_certbot*
%exclude %{python_sitelib}/letshelp_certbot/testdata

%files -n python-certbot
%defattr(-,root,root)
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-*
%exclude %{python_sitelib}/%{name}/tests

%files -n python-certbot-apache
%defattr(-,root,root)
%{python_sitelib}/%{name}_apache*
%exclude %{python_sitelib}/certbot_apache/tests

%files -n python-certbot-nginx
%defattr(-,root,root)
%{python_sitelib}/%{name}_nginx*
%exclude %{python_sitelib}/certbot_nginx/tests

%files -n python-certbot-dns-cloudflare
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_cloudflare*

%files -n python-certbot-dns-cloudxns
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_cloudxns*

%files -n python-certbot-dns-digitalocean
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_digitalocean*

%files -n python-certbot-dns-dnsimple
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_dnsimple*

%files -n python-certbot-dns-google
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_google*

%files -n python-certbot-dns-nsone
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_nsone*

%files -n python-certbot-dns-route53
%defattr(-,root,root)
%{python_sitelib}/%{name}_dns_route53*

%changelog
* Sun Jun 11 2017 ecsos@opensuse.org
- update to 0.15.0
  See https://github.com/certbot/certbot/blob/master/CHANGELOG.md
  and https://github.com/certbot/certbot/milestone/37?closed=1
* Wed Jun  7 2017 ecsos@opensuse.org
- add missing domain parameter in cli.ini
* Wed Jun  7 2017 ecsos@opensuse.org
- add missing dependency to python-future
- rework README.SUSE and certbot.cron
* Thu Jun  1 2017 ecsos@opensuse.org
- update to 0.14.2
  See https://github.com/certbot/certbot/milestone/40?closed=1
* Wed May 17 2017 ecsos@opensuse.org
- update to 0.14.1
  See https://github.com/certbot/certbot/milestone/39?closed=1
* Tue May 16 2017 ecsos@opensuse.org
- fix build error in Tumbleweed
* Mon May 15 2017 ecsos@opensuse.org
- update t 0.14.0
  See https://github.com/certbot/certbot/milestone/35?closed=1
* Tue Apr 25 2017 ecsos@opensuse.org
- update to 0.13.0
  See https://github.com/certbot/certbot/milestone/34?closed=1
* Mon Mar 27 2017 ecsos@opensuse.org
- insert BuildRequires: python-packaging to prevent build errors
  for Leap 42.1
* Mon Mar  6 2017 ecsos@opensuse.org
- change require version to python-requests >= 2.10
* Fri Mar  3 2017 ecsos@opensuse.org
- update to 0.12.0
  See https://github.com/certbot/certbot/milestone/31?closed=1
* Wed Feb  8 2017 ecsos@opensuse.org
- update to 0.11.1
  See https://github.com/certbot/certbot/milestone/33?closed=1
- update to 0.11.0
  See https://github.com/certbot/certbot/milestone/28?closed=1
* Sat Jan 28 2017 ecsos@opensuse.org
- update to 0.10.2
  See https://github.com/certbot/certbot/milestone/32?closed=1
* Tue Jan 17 2017 ecsos@opensuse.org
- update to 0.10.1
  See https://github.com/certbot/certbot/milestone/29?closed=1
* Wed Jan 11 2017 ecsos@opensuse.org
- update to 0.10.0
  See https://github.com/certbot/certbot/milestone/24?closed=1
* Fri Jan  6 2017 ecsos@opensuse.org
- rework README.SUSE
- fix sporadic build errors in doc section
* Tue Nov  1 2016 ecsos@opensuse.org
- change certbot-cli.ini.patch
  The flag standalone-supported-challenges is deprecated.
  It is now preferred-challenges instead.
* Thu Oct 20 2016 ecsos@opensuse.org
- update to 0.9.3
  See https://github.com/certbot/certbot/milestone/27?closed=1
- update to 0.9.2
  See https://github.com/certbot/certbot/milestone/26?closed=1
- update to 0.9.1
  See https://github.com/certbot/certbot/milestone/25?closed=1
* Wed Oct  5 2016 ecsos@opensuse.org
- update to 0.9.0
  See https://github.com/certbot/certbot/milestone/22?closed=1
* Mon Aug  1 2016 ecsos@opensuse.org
- python-requests >= 2.0 is required by certbot
* Fri Jul 15 2016 matwey.kornilov@gmail.com
- psutils >= 2.2.1 is required by certbot 0.8.1:
  File "/usr/lib/python2.7/site-packages/pkg_resources.py", line 639, in resolve
    raise DistributionNotFound(req)
  pkg_resources.DistributionNotFound: psutil>=2.2.1
* Sat Jun 18 2016 ecsos@opensuse.org
- update to 0.8.1
* Sun Jun  5 2016 ecsos@opensuse.org
- update to 0.8.0
* Tue May 31 2016 ecsos@opensuse.org
- update to 0.7.0
* Sat May 14 2016 ecsos@opensuse.org
- rename packge letsencrypt to new name certbot
- change letsencrypt to certbot in spec file
- obsolete letsencrypt in spec
- Add patch certbot-fix_constants.patch to fix path locations from
  letsencrypt to certbot
- update to 0.6.0
* Fri Apr  8 2016 ecsos@opensuse.org
- update to 0.5.0
* Wed Mar  9 2016 jweberhofer@weberhofer.at
- The /etc/letsencrypt/keys directory must exclusively be readable
  by root
* Wed Mar  9 2016 jweberhofer@weberhofer.at
- Fixed version dependency to python-setuptools
* Mon Mar  7 2016 ecsos@opensuse.org
- update to 0.4.2
* Tue Mar  1 2016 ecsos@opensuse.org
- update to 0.4.1
* Sun Feb 14 2016 ecsos@opensuse.org
- clean spec
- don't build python-acme anymore, use seperate package instead
  because of correct errors in man and to run test within package
  building
- move cli.ini changes from spec to patch file
- insert cron file
* Thu Feb 11 2016 ecsos@opensuse.org
- update to 0.4.0
* Fri Jan 29 2016 ecsos@opensuse.org
- update to 0.3.0
* Tue Jan 19 2016 ecsos@opensuse.org
- update to 0.2.0
- remove no more needed versionstag patch
* Fri Jan  1 2016 ecsos@opensuse.org
- add patch for versionstag mismatch
* Fri Dec 18 2015 ecsos@opensuse.org
- update to 0.1.1
* Sun Dec 13 2015 ecsos@opensuse.org
- update cli.ini parameters
* Fri Dec  4 2015 ecsos@opensuse.org
- change from nighly git version to latest beta version 0.1.0
* Sat Sep  5 2015 ecsos@opensuse.org
- add man pages
- add python-letsencrypt-apache and python-letsencrypt-nginx
* Fri Sep  4 2015 ecsos@opensuse.org
- add missing requirements
* Fri Aug  7 2015 ecsos@opensuse.org
- inititial version: developer preview
